@@ -19,8 +19,8 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>
  */
-#ifndef IP_UTIL_H
-# define IP_UTIL_H
+#ifndef OC_IP_UTIL_H
+# define OC_IP_UTIL_H
 
 #include <sys/socket.h>
 #include <netinet/in.h>
