@@ -23,9 +23,6 @@
 #include <string.h>
 #include <stdlib.h>
 #include <stdint.h>
-#ifndef _XOPEN_SOURCE
-# define _XOPEN_SOURCE
-#endif
 #include <unistd.h>
 #include <gnutls/gnutls.h>
 #include <gnutls/crypto.h>	/* for random */
@@ -37,10 +34,7 @@
    * in unistd.h */
 # include <crypt.h>
 #endif
-
-/* Gnulib portability files. */
-#include <getpass.h>
-#include <minmax.h>
+#include <locale.h>
 
 #define DEFAULT_OCPASSWD "/etc/ocserv/ocpasswd"
 
@@ -67,6 +61,9 @@ crypt_int(const char *fpasswd, const char *username, const char *groupname,
 	ssize_t len, l;
 	int ret;
 
+	setlocale(LC_CTYPE, "C");
+	setlocale(LC_COLLATE, "C");
+
 	ret = gnutls_rnd(GNUTLS_RND_NONCE, _salt, sizeof(_salt));
 	if (ret < 0) {
 		fprintf(stderr, "Error generating nonce: %s\n",
@@ -263,7 +260,7 @@ lock_user(const char *fpasswd, const char *username)
 				continue;
 			p++;
 
-			if(*p != '!') {
+			if (*p != '!') {
 				l = p-line;
 				fwrite(line, 1, l, fd2);
 				fputc('!', fd2);
@@ -428,48 +425,48 @@ int main(int argc, char **argv)
 		if (c == -1)
 			break;
 
-		switch(c) {
-			case 'c':
-				if (fpasswd) {
-					fprintf(stderr, "-c option cannot be specified multiple time\n");
-					exit(EXIT_FAILURE);
-				}
-				fpasswd = strdup(optarg);
-				break;
-			case 'g':
-				if (groupname) {
-					fprintf(stderr, "-g option cannot be specified multiple time\n");
-					exit(EXIT_FAILURE);
-				}
-				groupname = strdup(optarg);
-				break;
-			case 'd':
-				if (flags) {
-					usage();
-					exit(EXIT_FAILURE);
-				}
-				flags |= FLAG_DELETE;
-				break;
-			case 'u':
-				if (flags) {
-					usage();
-					exit(EXIT_FAILURE);
-				}
-				flags |= FLAG_UNLOCK;
-				break;
-			case 'l':
-				if (flags) {
-					usage();
-					exit(EXIT_FAILURE);
-				}
-				flags |= FLAG_LOCK;
-				break;
-			case 'h':
+		switch (c) {
+		case 'c':
+			if (fpasswd) {
+				fprintf(stderr, "-c option cannot be specified multiple time\n");
+				exit(EXIT_FAILURE);
+			}
+			fpasswd = strdup(optarg);
+			break;
+		case 'g':
+			if (groupname) {
+				fprintf(stderr, "-g option cannot be specified multiple time\n");
+				exit(EXIT_FAILURE);
+			}
+			groupname = strdup(optarg);
+			break;
+		case 'd':
+			if (flags) {
 				usage();
-				exit(EXIT_SUCCESS);
-			case 'v':
-				version();
-				exit(EXIT_SUCCESS);
+				exit(EXIT_FAILURE);
+			}
+			flags |= FLAG_DELETE;
+			break;
+		case 'u':
+			if (flags) {
+				usage();
+				exit(EXIT_FAILURE);
+			}
+			flags |= FLAG_UNLOCK;
+			break;
+		case 'l':
+			if (flags) {
+				usage();
+				exit(EXIT_FAILURE);
+			}
+			flags |= FLAG_LOCK;
+			break;
+		case 'h':
+			usage();
+			exit(EXIT_SUCCESS);
+		case 'v':
+			version();
+			exit(EXIT_SUCCESS);
 		}
 	}
 
