@@ -33,8 +33,7 @@
 
 #include <nettle/base64.h>
 #include <base64-helper.h>
-#include <c-strcase.h>
-#include <c-ctype.h>
+#include <ctype.h>
 
 #include <vpn.h>
 #include <worker.h>
@@ -75,6 +74,7 @@ static const struct known_urls_st known_urls[] = {
 	LL("/+CSCOT+/", get_string_handler, NULL),
 	LL("/logout", get_empty_handler, NULL),
 #endif
+	LL("/svc", get_svc_handler, post_svc_handler),
 	{NULL, 0, 0, NULL, NULL}
 };
 
@@ -104,7 +104,8 @@ static const dtls_ciphersuite_st ciphersuites[] = {
 	 .gnutls_mac = GNUTLS_MAC_AEAD,
 	 .gnutls_kx = GNUTLS_KX_RSA,
 	 .gnutls_cipher = GNUTLS_CIPHER_AES_128_GCM,
-	 .server_prio = 80},
+	 .server_prio = 80,
+	},
 	{
 	 .oc_name = CS_AES256_GCM,
 	 .gnutls_name =
@@ -114,7 +115,7 @@ static const dtls_ciphersuite_st ciphersuites[] = {
 	 .gnutls_kx = GNUTLS_KX_RSA,
 	 .gnutls_cipher = GNUTLS_CIPHER_AES_256_GCM,
 	 .server_prio = 90,
-	 },
+	},
 	{
 	 .oc_name = "AES256-SHA",
 	 .gnutls_name =
@@ -124,7 +125,7 @@ static const dtls_ciphersuite_st ciphersuites[] = {
 	 .gnutls_kx = GNUTLS_KX_RSA,
 	 .gnutls_cipher = GNUTLS_CIPHER_AES_256_CBC,
 	 .server_prio = 60,
-	 },
+	},
 	{
 	 .oc_name = "AES128-SHA",
 	 .gnutls_name =
@@ -134,7 +135,7 @@ static const dtls_ciphersuite_st ciphersuites[] = {
 	 .gnutls_kx = GNUTLS_KX_RSA,
 	 .gnutls_cipher = GNUTLS_CIPHER_AES_128_CBC,
 	 .server_prio = 50,
-	 },
+	},
 	{
 	 .oc_name = "DES-CBC3-SHA",
 	 .gnutls_name =
@@ -144,7 +145,7 @@ static const dtls_ciphersuite_st ciphersuites[] = {
 	 .gnutls_kx = GNUTLS_KX_RSA,
 	 .gnutls_cipher = GNUTLS_CIPHER_3DES_CBC,
 	 .server_prio = 1,
-	 }
+	},
 };
 
 static const dtls_ciphersuite_st ciphersuites12[] = {
@@ -169,6 +170,29 @@ static const dtls_ciphersuite_st ciphersuites12[] = {
 	 .gnutls_cipher = GNUTLS_CIPHER_AES_256_GCM,
 	 .dtls12_mode = 1,
 	 .server_prio = 90
+	},
+	/* these next two are currently only used by cisco-svc-client-compat devices */
+	{
+	 .oc_name = "ECDHE-RSA-AES128-GCM-SHA256",
+	 .gnutls_name =
+	 "NONE:+VERS-DTLS1.2:+COMP-NULL:+AES-128-GCM:+AEAD:+SHA256:+ECDHE-RSA:+SIGN-ALL:"WORKAROUND_STR,
+	 .gnutls_version = GNUTLS_DTLS1_2,
+	 .gnutls_mac = GNUTLS_MAC_AEAD,
+	 .gnutls_kx = GNUTLS_KX_ECDHE_RSA,
+	 .gnutls_cipher = GNUTLS_CIPHER_AES_128_GCM,
+	 .dtls12_mode = 1,
+	 .server_prio = 70,
+	},
+	{
+	 .oc_name = "ECDHE-RSA-AES256-GCM-SHA384",
+	 .gnutls_name =
+	 "NONE:+VERS-DTLS1.2:+COMP-NULL:+AES-256-GCM:+AEAD:+SHA384:+ECDHE-RSA:+SIGN-ALL:"WORKAROUND_STR,
+	 .gnutls_version = GNUTLS_DTLS1_2,
+	 .gnutls_mac = GNUTLS_MAC_AEAD,
+	 .gnutls_kx = GNUTLS_KX_ECDHE_RSA,
+	 .gnutls_cipher = GNUTLS_CIPHER_AES_256_GCM,
+	 .dtls12_mode = 1,
+	 .server_prio = 80,
 	}
 };
 
@@ -242,7 +266,7 @@ unsigned switch_comp_priority(void *pool, const char *modstring)
 		goto finish;
 	}
 	for (i = 0; i < ARRAY_SIZE(comp_methods); i++) {
-		if (c_strcasecmp(algo, comp_methods[i].name) == 0) {
+		if (strcasecmp(algo, comp_methods[i].name) == 0) {
 			comp_methods[i].server_prio = priority;
 			ret = 1;
 			goto finish;
@@ -423,6 +447,9 @@ void header_value_check(struct worker_st *ws, struct http_req_st *req)
 		} else if (strncasecmp(req->user_agent, "AnyLink Secure Client", 21) == 0) {
 			oclog(ws, LOG_DEBUG, "Detected AnyLink");
 			req->user_agent_type = AGENT_ANYLINK;
+		} else if (strncasecmp(req->user_agent, "Cisco SVC IPPhone Client", 24) == 0) {
+			oclog(ws, LOG_DEBUG, "Detected Cisco SVC IPPhone Client");
+			req->user_agent_type = AGENT_SVC_IPPHONE;
 		} else {
 			oclog(ws, LOG_DEBUG, "Unknown client (%s)", req->user_agent);
 		}
@@ -471,7 +498,7 @@ void header_value_check(struct worker_st *ws, struct http_req_st *req)
 						if (want_cipher != -1) {
 							if (want_cipher == cand->gnutls_cipher &&
 							    want_mac == cand->gnutls_mac)
-							    goto ciphersuite_finish;
+								goto ciphersuite_finish;
 						}
 					}
 				}
@@ -536,7 +563,7 @@ void header_value_check(struct worker_st *ws, struct http_req_st *req)
 						if (want_cipher != -1) {
 							if (want_cipher == cand->gnutls_cipher &&
 							    want_mac == cand->gnutls_mac)
-							    goto ciphersuite12_finish;
+								goto ciphersuite12_finish;
 						}
 					}
 				}
@@ -565,7 +592,7 @@ void header_value_check(struct worker_st *ws, struct http_req_st *req)
 		str = (char *)value;
 		while ((token = strtok(str, ",")) != NULL) {
 			for (i = 0; i < ARRAY_SIZE(comp_methods); i++) {
-				if (c_strcasecmp(token, comp_methods[i].name) == 0) {
+				if (strcasecmp(token, comp_methods[i].name) == 0) {
 					if (comp_cand == NULL ||
 					    comp_cand->server_prio <
 					    comp_methods[i].server_prio) {
@@ -604,7 +631,7 @@ void header_value_check(struct worker_st *ws, struct http_req_st *req)
 		str = (char *)value;
 		while ((token = strtok(str, ";")) != NULL) {
 			p = token;
-			while (c_isspace(*p)) {
+			while (isspace(*p)) {
 				p++;
 			}
 			tmplen = strlen(p);
@@ -613,7 +640,7 @@ void header_value_check(struct worker_st *ws, struct http_req_st *req)
 				tmplen -= 7;
 				p += 7;
 
-				while (tmplen > 1 && c_isspace(p[tmplen - 1])) {
+				while (tmplen > 1 && isspace(p[tmplen - 1])) {
 					tmplen--;
 				}
 
@@ -644,7 +671,7 @@ void header_value_check(struct worker_st *ws, struct http_req_st *req)
 				p += 14;
 				tmplen -= 14;
 
-				while (tmplen > 1 && c_isspace(p[tmplen - 1])) {
+				while (tmplen > 1 && isspace(p[tmplen - 1])) {
 					tmplen--;
 				}
 
@@ -698,12 +725,17 @@ url_handler_fn http_get_url_handler(const char *url)
 url_handler_fn http_post_url_handler(struct worker_st *ws, const char *url)
 {
 	const struct known_urls_st *p;
+	unsigned len = strlen(url);
 	unsigned i;
 
 	p = known_urls;
 	do {
-		if (p->url != NULL && strcmp(p->url, url) == 0)
-			return p->post_handler;
+		if (p->url != NULL) {
+			if ((len == p->url_size && strcmp(p->url, url) == 0) ||
+			    (len > p->url_size && strncmp(p->url, url, p->url_size) == 0
+			     && p->partial_match == 0 && url[p->url_size] == '?'))
+				return p->post_handler;
+		}
 		p++;
 	} while (p->url != NULL);
 
@@ -873,7 +905,7 @@ int add_owasp_headers(worker_st * ws)
 {
 	unsigned i;
 
-	for(i=0; i < GETCONFIG(ws)->included_http_headers_size; i++)
+	for (i=0; i < GETCONFIG(ws)->included_http_headers_size; i++)
 	{
 		if (cstp_printf(ws, "%s", GETCONFIG(ws)->included_http_headers[i]) < 0 ||
 		    cstp_puts(ws, "\r\n") < 0)
