@@ -829,6 +829,9 @@ void vpn_server(struct worker_st *ws)
 			      "could not parse proxy protocol header; discarding connection");
 			exit_worker(ws);
 		}
+
+		/* update ws->remote_ip_str */
+		human_addr2((const struct sockaddr *)&ws->remote_addr, ws->remote_addr_len, ws->remote_ip_str, sizeof(ws->remote_ip_str), 0);
 	} else {
 		oclog(ws, LOG_DEBUG, "accepted connection");
 	}
@@ -875,6 +878,7 @@ void vpn_server(struct worker_st *ws)
 		do {
 			ret = gnutls_handshake(session);
 		} while (ret < 0 && gnutls_error_is_fatal(ret) == 0);
+		GNUTLS_ALERT_PRINT(ws, session, ret);
 		GNUTLS_FATAL_ERR(ret);
 
 		oclog(ws, LOG_DEBUG, "TLS handshake completed");
@@ -1455,6 +1459,7 @@ static int dtls_mainloop(worker_st * ws, struct dtls_st * dtls, struct timespec
 			} while (ret == GNUTLS_E_AGAIN
 				 || ret == GNUTLS_E_INTERRUPTED);
 
+			GNUTLS_ALERT_PRINT(ws, dtls->dtls_session, ret);
 			DTLS_FATAL_ERR_CMD(ret, exit_worker_reason(ws, REASON_ERROR));
 			oclog(ws, LOG_DEBUG, "DTLS rehandshake completed");
 
@@ -1597,6 +1602,7 @@ static int tls_mainloop(struct worker_st *ws, struct timespec *tnow)
 		do {
 			ret = gnutls_handshake(ws->session);
 		} while (ret < 0 && gnutls_error_is_fatal(ret) == 0);
+		GNUTLS_ALERT_PRINT(ws, ws->session, ret);
 		DTLS_FATAL_ERR_CMD(ret, exit_worker_reason(ws, REASON_ERROR));
 
 		ws->last_tls_rehandshake = tnow->tv_sec;
@@ -1917,7 +1923,9 @@ static int connect_handler(worker_st * ws)
 
 	cookie_authenticate_or_exit(ws);
 
-	if (strcmp(req->url, "/CSCOSSLC/tunnel") != 0) {
+	/* The Clavister Android VPN client has a defect and
+	 * asks for CSCOSSLC/tunnel instead of /CSCOSSLC/tunnel */
+	if (strcmp(req->url, "/CSCOSSLC/tunnel") != 0 && strcmp(req->url, "CSCOSSLC/tunnel") != 0) {
 		oclog(ws, LOG_INFO, "bad connect request: '%s'\n", req->url);
 		response_404(ws, 1);
 		cstp_fatal_close(ws, GNUTLS_A_ACCESS_DENIED);
