@@ -23,7 +23,7 @@
 #include "../src/ip-util.h"
 #include "../src/ip-util.c"
 
-int main()
+int main(void)
 {
 	char *p;
 
